import axios from 'axios'
import { IMonthlyNews } from '../models/monthlyNews.model'
import { IPoll } from '../models/poll.model'
import { toast } from 'react-toastify'
export class MonthlyNewsService {
  private readonly _apiUrl: string
  constructor() {
    this._apiUrl = 'https://localhost:1443/'
  }
  /**
   * Creates a quotation and header for selected month
   * @param date
   * @param header
   * @param quote
   */
  public createMonthlyReport = async (
    date: Date,
    header: string,
    quote: string,
    token: string
  ): Promise<void> => {
    try {
      await axios.post(
        `${this._apiUrl}api/admin/monthlyNews`,
        {
          month: date.getMonth(),
          year: date.getFullYear(),
          header: header,
          quote: quote,
        },
        {
          headers: {
            'XSRF-TOKEN': token,
          },
        }
      )
      toast.success('Monthly news succesfully created !')
    } catch (e) {
      toast.error('Failed to create monthly news')
      console.log(e)
    }
  }

  /**
   * Gets a quotation and header for selected month
   */
  public getSingleMonthlyReport = async (
    year: number,
    month: number,
    token: string
  ): Promise<IMonthlyNews | null> => {
    try {
      const { data } = await axios.get(
        `${this._apiUrl}api/admin/monthlyNews/${year}/${month}`,
        {
          headers: {
            'XSRF-TOKEN': token,
          },
        }
      )
      console.log('monthlyFetched', data)
      if (data == {}) {
        return null
      }

      return data as IMonthlyNews
    } catch (e) {
      console.log('error', e)
      return null
    }
  }

  /**
   * Gets a poll with question and link for selected month
   */
  public getSinglePoll = async (
    year: number,
    month: number,
    token: string
  ): Promise<IPoll | null> => {
    try {
      const { data } = await axios.get(
        `${this._apiUrl}api/admin/poll/${year}/${month}`,
        {
          headers: {
            'XSRF-TOKEN': token,
          },
        }
      )
      if (data === {}) {
        return null
      }
      return data as IPoll
    } catch (e) {
      console.log('error', e)
      return null
    }
  }

  /**
   * Creates a poll with question and link for selected month
   * @param date
   * @param question
   * @param link
   */
  public createPoll = async (
    date: Date,
    question: string,
    link: string,
    token: string
  ): Promise<void> => {
    try {
      await axios.post(
        `${this._apiUrl}api/admin/poll`,
        {
          month: date.getMonth(),
          year: date.getFullYear(),
          link: link,
          question: question,
        },
        {
          headers: {
            'XSRF-TOKEN': token,
          },
        }
      )
      toast.success('Poll succesfully created !')
    } catch (e) {
      toast.error('Failed to create poll')
      console.log(e)
    }
  }
}
